import { buildUUID } from '../../../utils/uuid';
import { ApiAction, ApiActionPage } from '../../model/baseModel';
import {
  MesWslistPageParams,
  MES_WORKSHOPPageListGetResultModel,
  MES_WORKSHOP,
} from '../model/mesModel';
import { genAction, Api, genActionPage } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { useUserStore } from '../../../store/modules/user';
import { isNullOrEmpty } from '/@/utils/is';
import { mesApi } from '../mes/mesApi';

/*
 * 获取车间分页列表
 */
export const getWsListByPage = async (params: MesWslistPageParams) => {
  let sqlcmd = '';
  if (!isNullOrEmpty(params?.WS_CODE)) {
    sqlcmd += `And WS_CODE like '%${params?.WS_CODE}%'`;
  }
  if (!isNullOrEmpty(params?.WS_NAME)) {
    sqlcmd += `And ITEM_CODE like '${params?.WS_NAME}%'`;
  }
  const rParams = genActionPage('MES_WORKSHOP', sqlcmd, params.page, params.pageSize);
  return getWsListByPageAsync(rParams);
};
async function getWsListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
    },
  );
  const model: MES_WORKSHOPPageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
  };
  return model;
}

//保存
export const SaveMesWs = async (params: MES_WORKSHOP) => {
  params.CREATE_USER = useUserStore().getUserInfo.userId as string;
  params.UPDATE_USER = useUserStore().getUserInfo.userId as string;
  const data = await defHttp.post(
    { url: mesApi.SaveMesWs, params: genAction('MES_WORKSHOP', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};

/*
 * 删除车间
 */
export const DeleteMesWs = async (params: string) => {
  const usParams = genAction('MES_WORKSHOP', params);
  return await defHttp.post(
    { url: mesApi.DeleteMesWs, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};
